package Bencher::Scenarios::DataSahResolve;

our $DATE = '2021-08-01'; # DATE
our $VERSION = '0.004'; # VERSION

1;
# ABSTRACT: Benchmark Data::Sah::Resolve

__END__

=pod

=encoding UTF-8

=head1 NAME

Bencher::Scenarios::DataSahResolve - Benchmark Data::Sah::Resolve

=head1 VERSION

This document describes version 0.004 of Bencher::Scenarios::DataSahResolve (from Perl distribution Bencher-Scenarios-DataSahResolve), released on 2021-08-01.

=head1 DESCRIPTION

This distribution contains the following L<Bencher> scenario modules:

=over

=item * L<Bencher::Scenario::DataSahResolve::Overhead>

=item * L<Bencher::Scenario::DataSahResolve::Resolve>

=back

=head1 CONTRIBUTOR

=for stopwords perlancar (@pc-office)

perlancar (@pc-office) <perlancar@gmail.com>

=head1 HOMEPAGE

Please visit the project's homepage at L<https://metacpan.org/release/Bencher-Scenarios-DataSahResolve>.

=head1 SOURCE

Source repository is at L<https://github.com/perlancar/perl-Bencher-Scenarios-DataSahResolve>.

=head1 BUGS

Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Bencher-Scenarios-DataSahResolve>

When submitting a bug or request, please include a test-file or a
patch to an existing test-file that illustrates the bug or desired
feature.

=head1 AUTHOR

perlancar <perlancar@cpan.org>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2021, 2017, 2016 by perlancar@cpan.org.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
